package com.srs.dormitory.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.dormitory.domain.DmsNewWenming;
import com.srs.dormitory.domain.Dto.DmsSearch;
import com.srs.dormitory.domain.Dto.WenMingImport;
import com.srs.dormitory.domain.Vo.DomInfo;

/**
 * 文明宿舍Service接口
 *
 * @author srs
 * @date 2024-03-28
 */
public interface IDmsNewWenmingService extends IService<DmsNewWenming> {


    List<DomInfo> listView(DmsSearch param);


    /**
     * 查询文明宿舍
     *
     * @param id 文明宿舍主键
     * @return 文明宿舍
     */
    public DmsNewWenming selectDmsNewWenmingById(Long id);

    /**
     * 查询文明宿舍列表
     *
     * @param dmsNewWenming 文明宿舍
     * @return 文明宿舍集合
     */
    List<DmsNewWenming> selectDmsNewWenmingList(DmsNewWenming dmsNewWenming);

    /**
     * 导入文明宿舍
     *
     */

     public String importWenMing(List<DmsNewWenming> wemingList, String operName);

    /**
     * 新增文明宿舍
     *
     * @param dmsNewWenming 文明宿舍
     * @return 结果
     */
    int insertDmsNewWenming(DmsNewWenming dmsNewWenming);

    /**
     * 修改文明宿舍
     *
     * @param dmsNewWenming 文明宿舍
     * @return 结果
     */
    int updateDmsNewWenming(DmsNewWenming dmsNewWenming);

    /**
     * 批量删除文明宿舍
     *
     * @param ids 需要删除的文明宿舍主键集合
     * @return 结果
     */
    int deleteDmsNewWenmingByIds(Long[] ids);

    /**
     * 删除文明宿舍信息
     *
     * @param id 文明宿舍主键
     * @return 结果
     */
    int deleteDmsNewWenmingById(Long id);
}
